clear_cached_resources: Clear cached taxonomic resources

View source: R/load_taxonomic_resources.R

clear_cached_resourcesR Documentation

Clear cached taxonomic resources

Description

Removes any taxonomic resources that have been cached in memory during the current R session. After calling this function, the next call to load_taxonomic_resources() will re-download and re-process the data.

Usage

clear_cached_resources()

Details

This is useful if you want to force a reload of the resources, for example after updating the package or switching to a different version.

Value

Invisibly returns NULL.

Examples

clear_cached_resources()

APCalign documentation built on Sept. 9, 2026, 9:07 a.m.