standardise_names: Standardise taxon names

View source: R/standardise_names.R

standardise_namesR Documentation

Standardise taxon names

Description

Standardises taxon names by performing a series of text substitutions to remove common inconsistencies in taxonomic nomenclature.

The function takes a character vector of taxon names as input and returns a character vector of taxon names using standardised taxonomic syntax as output.

Usage

standardise_names(taxon_names)

Arguments

taxon_names

A character vector of taxon names that need to be standardised.

Details

  • It removes stray punctuation at the start and end of a character string.

  • It standardises unusual characters and symbols to ASCII equivalents.

  • It standardises taxon rank abbreviations and qualifiers (subsp., var., f.), as people use many variants of these terms.

  • It standardises or removes a few additional filler words used within taxon names (affinis becomes aff.; s.l. and s.s. are removed).

affinis is only treated as an affinity qualifier where it cannot be a species epithet: it is left alone at the end of a name (⁠Acacia affinis⁠) and before a rank marker (⁠Gomphrena affinis subsp. pilbarensis⁠).

Value

A character vector of standardised taxon names.

Examples

standardise_names(c("Quercus suber",
                    "Eucalyptus sp.",
                    "Eucalyptus spp.",
                    "Agave americana var. marginata",
                    "Agave americana v marginata",
                    "Notelaea longifolia forma longifolia",
                    "Notelaea longifolia f longifolia",
                    "Acacia affinis dealbata",
                    "Gomphrena affinis subsp. pilbarensis"))

APCalign documentation built on Sept. 9, 2026, 9:07 a.m.