View source: R/synonyms_for_accepted_names.R
| synonyms_for_accepted_names | R Documentation |
This function generates lists a string of synonyms for currently accepted species and infra-species to facilitate working out past names of a taxon when the current name is known.
synonyms_for_accepted_names(
accepted_names,
collapse = TRUE,
resources = load_taxonomic_resources()
)
accepted_names |
A character vector of currently accepted taxon names to look up synonyms for. |
collapse |
Offering the option to return a long data table with each synonym in its own row, versus collapsed into a vector for each accepted name |
resources |
Taxonomic resources loaded via |
A table with the currently accepted name and columns documenting all synonyms and all synonyms with taxonomic status.
synonyms_for_accepted_names(
accepted_names = c("Justicia tenella", "Acacia aneura"),
collapse = TRUE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.