View source: R/load_taxonomic_resources.R
| clear_cached_resources | R Documentation |
Removes any taxonomic resources that have been cached in memory during the
current R session. After calling this function, the next call to
load_taxonomic_resources() will re-download and re-process the data.
clear_cached_resources()
This is useful if you want to force a reload of the resources, for example after updating the package or switching to a different version.
Invisibly returns NULL.
clear_cached_resources()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.