Removes any taxonomic resources that have been cached in memory during the
current R session. After calling this function, the next call to
load_taxonomic_resources() will re-download and re-process the data.
Removes any taxonomic resources that have been cached in memory during the
current R session. After calling this function, the next call to
load_taxonomic_resources() will re-download and re-process the data.