View source: R/load_taxonomic_resources.R
| load_taxonomic_resources | R Documentation |
This function loads two taxonomic datasets for Australia's vascular plants, the APC and APNI. It creates several data frames by filtering and selecting data from the loaded lists.
load_taxonomic_resources(
stable_or_current_data = "stable",
version = default_version(),
quiet = FALSE
)
stable_or_current_data |
Type of dataset to access. The default is "stable", which loads the dataset from a github archived file. If set to "current", the dataset will be loaded from a URL which is the cutting edge version, but this may change at any time without notice. |
version |
The version number of the dataset to use. Defaults to the default version. |
quiet |
A logical indicating whether to print status of loading to screen. Defaults to FALSE. |
It accesses taxonomic data from a dataset using the provided version number or the default version.
The output is several dataframes that include subsets of the APC/APNI based on taxon rank and taxonomic status.
Results are cached in memory for the R session so that repeated calls with
the same version and stable_or_current_data arguments return immediately
without re-downloading or re-processing the data. Use
clear_cached_resources() to force a reload.
"current" data is not cached because it may change between calls.
A list of taxonomic resource data frames.
load_taxonomic_resources(stable_or_current_data="stable",
version="2024-10-11")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.